@@ -56,12 +56,21 @@ def format_datetime(dt):
             d = int(dt.split('天')[0].strip())
             ret = (datetime.datetime.now() - datetime.timedelta(days=d)).strftime("%Y-%m-%d %H:%M:%S")
         elif '昨天' in dt:
-            tt = dt.split('昨天')[-1].strip()
-            strdate = (datetime.datetime.now() - datetime.timedelta(days=1)).strftime("%Y-%m-%d ") + tt
-            df = datetime.datetime.strptime(strdate, '%Y-%m-%d %H:%M')
-            ret = datetime.datetime.strftime(df, '%Y-%m-%d %H:%M:%S')
+            if len(re.findall(r'\d', dt)) > 0:
+                tt = dt.split('昨天')[-1].strip()
+                strdate = (datetime.datetime.now() - datetime.timedelta(days=1)).strftime("%Y-%m-%d ") + tt
+                df = datetime.datetime.strptime(strdate, '%Y-%m-%d %H:%M')
+                ret = datetime.datetime.strftime(df, '%Y-%m-%d %H:%M:%S')
+            else:
+                ret = (datetime.datetime.now() - datetime.timedelta(days=1)).strftime("%Y-%m-%d %H:%M:%S")
         elif '前天' in dt:
-            ret = (datetime.datetime.now() - datetime.timedelta(days=2)).strftime("%Y-%m-%d %H:%M:%S")
+            if len(re.findall(r'\d', dt)) > 0:
+                tt = dt.split('前天')[-1].strip()
+                strdate = (datetime.datetime.now() - datetime.timedelta(days=2)).strftime("%Y-%m-%d ") + tt
+                df = datetime.datetime.strptime(strdate, '%Y-%m-%d %H:%M')
+                ret = datetime.datetime.strftime(df, '%Y-%m-%d %H:%M:%S')
+            else:
+                ret = (datetime.datetime.now() - datetime.timedelta(days=2)).strftime("%Y-%m-%d %H:%M:%S")
         elif re.search(pattern, dt):
             result = re.search(pattern, dt)
             r = result.group(0)
@@ -89,7 +98,10 @@ def format_datetime(dt):
             strdate = str(datetime.datetime.now().year) + '-' + dt
             dtformat = re.sub('[月/]', '-', strdate)
             dtformat = re.sub('日', '', dtformat).strip()
-            dtformat = datetime.datetime.strptime(strdate, '%Y-%m-%d')
+            try:
+                dtformat = datetime.datetime.strptime(strdate, '%Y-%m-%d')
+            except Exception:
+                dtformat = datetime.datetime.strptime(dtformat, '%Y-%m-%d')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
         elif re.search(pattern2, dt):
             dt = re.search(pattern2, dt).group(0)
